# -*- coding: utf-8 -*-

# Copyright(C) 2012-2014 Florent Fourcot
# Copyright(C) 2018      Eric Seigne
#
# This file is part of weboob.
#
# weboob is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# weboob is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with weboob. If not, see <http://www.gnu.org/licenses/>.
from datetime import datetime
from dateutil.relativedelta import relativedelta

from weboob.browser import LoginBrowser, URL, need_login
from weboob.browser.exceptions import ClientError, ServerError
from weboob.browser.filters.standard import CleanDecimal, Date
from weboob.tools.compat import basestring
from weboob.exceptions import BrowserIncorrectPassword
from weboob.capabilities.bill import Detail
from weboob.tools.compat import urlencode
from decimal import Decimal
from .pages import LoginPage, HomePage, AccountPage, BillsPage

__all__ = ['AmeliProBrowser']

class UlysBrowser(LoginBrowser):
    BASEURL   = 'https://espaceabonnes.vinci-autoroutes.com'

    loginp     = URL('/Authentification','https://oidc-bcu.vinci-autoroutes.com/tlp/login', LoginPage)
    homep      = URL(r'/$', HomePage)
    accountp   = URL('/InfosPersonnelles/CoordonneesFacturation', AccountPage)
    billsp     = URL('/FacturesConso/Factures', BillsPage)

    logged = False

    def __init__(self, config=None, *args, **kwargs):
        self.config = config
        kwargs['username'] = self.config['login'].get()
        kwargs['password'] = self.config['password'].get()
        super(UlysBrowser, self).__init__(*args, **kwargs)

    def do_login(self):
        self.logger.debug('call Browser.do_login')
        if self.logged:
            return True
        assert isinstance(self.username, basestring)
        assert isinstance(self.password, basestring)

        self.loginp.stay_or_go()
        if self.homep.is_here():
            self.logged = True
            return True

        self.page.login(self.username, self.password)
        if not self.homep.is_here():
            raise BrowserIncorrectPassword()

        self.logged = True

    @need_login
    def get_subscription_list(self):
        self.logger.debug('call Browser.get_subscription_list')
        self.accountp.stay_or_go()
        return self.page.iter_subscription_list()

    @need_login
    def get_subscription(self, id):
        self.logger.debug('call Browser.get_subscription')
        assert isinstance(id, basestring)
        return self.get_subscription_list()

    @need_login
    def iter_history(self, subscription):
        self.logger.debug('call Browser.iter_history')
        self.searchp.stay_or_go()


    @need_login
    def get_details(self, sub):
        self.logger.debug('call Browser.get_details')
        det = Detail()
        det.id = sub.id
        det.label = sub.label
        det.infos = ''
        det.price = Decimal('0.0')
        return det

    @need_login
    def iter_documents(self,subscription):
        self.logger.debug('call Browser.iter_document')
#        self.billsp.stay_or_go()
#        return self.page.iter_documents()
        documents = []
        self.billsp.go(subid=subscription.id)
        for b in self.page.get_bills(subid=subscription.id):
            documents.append(b)
        return iter(documents)

    @need_login
    def get_document(self, id):
        self.logger.debug('call Browser.get_document')
        self.billsp.stay_or_go()
        for b in self.page.get_bills(id) :
            if id == b.id:
                return b
        return False

