# -*- coding: utf-8 -*-

# Copyright(C) 2015      Vincent Paredes
# Copyright(C) 2018      Eric Seigne
#
# This file is part of weboob.
#
# weboob is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# weboob is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with weboob. If not, see <http://www.gnu.org/licenses/>.

from __future__ import unicode_literals

import re
try:
    from html.parser import HTMLParser
except ImportError:
    import HTMLParser

from weboob.browser.pages import HTMLPage, LoggedPage
from weboob.capabilities.bill import Subscription
from weboob.browser.elements import DictElement, ListElement, ItemElement, method, TableElement
from weboob.browser.filters.standard import CleanDecimal, CleanText, Env, Field, Regexp, Date, Currency, BrowserURL, Format
from weboob.browser.filters.html import Link, TableCell
from weboob.capabilities.base import NotAvailable
from weboob.capabilities.bill import DocumentTypes, Bill
from weboob.tools.date import parse_date
from weboob.tools.compat import urlencode
from datetime import datetime
from weboob.tools.compat import urljoin

class LoginPage(HTMLPage):
    def on_load(self):
        if self.doc.xpath('//p[contains(text(), "You have activated the double factor authentication")]'):
            raise AuthMethodNotImplemented('Two-Factor authentication is not supported.')

    @method
    def is_login_ok(self):
        return not self.doc.xpath('//form//input[@placeholder="username"]')

    def login(self, login, password):
        form = self.get_form(name='form')
        form['username'] = login
        form['password'] = password
        form.submit()

class HomePage(HTMLPage):
    def on_loaded(self):
        pass

class SubscriptionsPage(LoggedPage, HTMLPage):
    @method
    class get_item(ItemElement):
        klass = Subscription

        def obj_subscriber(self):
            try:
                return Regexp(CleanText('//div[contains(@class, "darkblue")]'), self.page.browser.L_SUBSCRIBER)(self)
            except RegexpError:
                return self.page.browser.username

        obj_id = 'ulys'

        def obj_label(self):
            return self.page.browser.username

class AccountPage(HTMLPage):
    def iter_subscription_list(self):
        ident = self.doc.xpath('//span[@class="PaddingLeft20 darkblue"]')[0]
        name = re.sub('^.*Bienvenue (.*) - Num.*', '\\1', ident.text)
        number = re.sub('^.* Client : ','',ident.text)
        sub = Subscription(number)
        sub._id = number
        sub.label = unicode(name)
        sub.subscriber = unicode(name)
        return sub


class BillsPage(LoggedPage, HTMLPage):
    @method
    class get_bills(TableElement):
        item_xpath = '//table/tbody/tr'
	head_xpath = '//table/thead/tr/th'
        flush_at_end = True

        col_numero           = re.compile(r'.*N.* DE FACTURE.*')
	col_amount           = 'MONTANT TTC'
	col_mois             = 'MOIS'
        col_date             = re.compile(r'.*DATE DE PR.*VEMENT.*')
        col_url              = re.compile(r'.*FACTURES / RELEV.*S.*')
        
        class item(ItemElement):
            klass = Bill

            obj_type = DocumentTypes.BILL
            obj_format = u"pdf"

            def obj_label(self):
                return CleanText(TableCell('mois')(self))(self)

            def obj_id(self):
                return CleanText(TableCell('numero')(self))(self)
                #return '%s-%s' % (Env('subid')(self), CleanText(TableCell('_numero')))

            def obj_url(self):
                return urljoin(self.page.url, Link('.//a')(TableCell('url')(self)[0]))

            #ici ...
            def obj_date(self):
                return datetime.strptime(CleanText(TableCell('date')(self))(self), '%d/%m/%Y').date()

            def obj_price(self):
                return CleanDecimal(Regexp(CleanText(TableCell('amount')), '.*?([\d,]+).*', default=NotAvailable), replace_dots=True, default=NotAvailable)(self)

            def obj_currency(self):
                return Currency(TableCell('amount')(self))(self)

